import React, { useEffect, useState } from 'react'
import { Link, useLocation, useParams } from 'react-router-dom'
import axios from 'axios'
import { API_BASE_URL, SITE_TITLE } from '../config'

type Post = { id:         number
              url:        string
              title:      string
              thumbnail:  string
              tags:       { name: string }[] }

const PostDetailPage = () => {
  const { id } = useParams ()
  const [post, setPost] = useState<Post | null> (null)

  const location = useLocation ()

  useEffect (() => {
    if (!(id))
      return
    void (axios.get (`/api/posts/${ id }`)
          .then (res => setPost (res.data))
          .catch (err => console.error ('うんち!', err)))
  }, [id])

  if (!(post))
    return <div>Loading...</div>

  document.title = `${ post.url } | ${ SITE_TITLE }`

  return (
      <div className="p-4">
        <h1 className="text-2xl font-bold mb-2">{post.url}</h1>
        <img src={post.thumbnail} alt={post.url} className="mb-4 max-w-lg" />
        <p className="mb-2">{post.description}</p>
        <div className="text-sm text-gray-600">
          タグ:
          {post.tags.map(tag => (
            <span key={tag.name} className="ml-2 px-2 py-1 bg-gray-200 rounded">
              #{tag.name}
            </span>
          ))}
        </div>
      </div>
      )
}

export default PostDetailPage
